#!/bin/bash
# Setup passwordless ssh for `oneadmin` (authorized_keys and known_hosts)

set -e -x -a

# Include config
. config/all_vars

key_hosts=${key_hosts:-$opennebula_hosts}

# Generate keys if not yet
for play_host in $key_hosts; do
    ssh root@$play_host <<EOF
set -e -x
if [ ! -f /var/lib/one/.ssh/id_rsa.pub ]; then
    su - oneadmin -c 'ssh-keygen -t rsa -f /var/lib/one/.ssh/id_rsa -q -P ""'
fi
EOF
done

# Gather host keys
ssh-keyscan $opennebula_hosts > tmp$$
for play_host in $key_hosts; do
    ssh root@$play_host "ssh-keyscan $int_ips" >> tmp$$
    break
done
for play_host in $key_hosts; do
    cat tmp$$ > hostkeys$$
    ssh root@$play_host 'cat /var/lib/one/.ssh/known_hosts || true' >> hostkeys$$
    cat hostkeys$$ | sort | uniq | ssh root@$play_host 'cat > /var/lib/one/.ssh/known_hosts'
    rm hostkeys$$
done
rm tmp$$

# Gather oneadmin keys
> tmp$$
for host in $opennebula_hosts; do
    ssh root@$host 'cat /var/lib/one/.ssh/id_rsa.pub' >> tmp$$
done
for play_host in $key_hosts; do
    ssh root@$play_host 'cat /var/lib/one/.ssh/authorized_keys || true' >> tmp$$
    cat tmp$$ | sort | uniq | ssh root@$play_host 'cat > /var/lib/one/.ssh/authorized_keys'
done
rm tmp$$
